==> voxstorm-0.3.1.tar.bz2: voxstorm-0.3.1/src/ctrackinf.h <==
/***************************************************************************/
/*! \file   ctrackinf.h
    \brief  饹STrackInfΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  16:23:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef CTRACKINF_H
#define CTRACKINF_H

#include <qstring.h>
#include <qdatetime.h>
#include <csourceformat.h>

/*-------------------------------------------------------------------------*/
/*! \class  CTrackInf
    \brief  ȥå
*/
/*-------------------------------------------------------------------------*/
class CTrackInf
{
public:
  CTrackInf();
  ~CTrackInf();

  //! ȥå̾Ρ
  QString strTrackName;
  //! ե̾Ρ
  QString strFileName;
  //! ϥǥХ
  QString strInputDevice;
  //! ϥǥХ
  QString strOutputDevice;
  //! ٥롣
  int  nLevel;
  //! ѥ
  int  nPan;
  //! ϰ()
  QTime timeStartPosition;
  //! եåȡ
  QTime timeOffset;
  //! ֡
  QTime timeLength;
  //! ߥ塼Ⱦ֡
  bool bMute;
  //! ϿݡȾ֡
  bool bRecPort;
};

#endif

==> voxstorm-0.4.1.tar.bz2: voxstorm-0.4.1/src/ctrackinf.h <==
/***************************************************************************/
/*! \file   ctrackinf.h
    \brief  饹STrackInfΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  16:23:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef CTRACKINF_H
#define CTRACKINF_H

#include <qstring.h>
#include <qdatetime.h>
#include <qvaluevector.h>
#include "csourceformat.h"
#include "cladspaeffect.h"

/*-------------------------------------------------------------------------*/
/*! \class  CTrackInf
    \brief  ȥå
*/
/*-------------------------------------------------------------------------*/
class CTrackInf
{
public:
  CTrackInf();
  ~CTrackInf();

  //! ȥå̾Ρ
  QString strTrackName;
  //! ե̾Ρ
  QString strFileName;
  //! ϥǥХ
  QString strInputDevice;
  //! ϥǥХ
  QString strOutputDevice;
  //! ٥롣
  int  nLevel;
  //! ѥ
  int  nPan;
  //! ϰ()
  QTime timeStartPosition;
  //! եåȡ
  QTime timeOffset;
  //! ֡
  QTime timeLength;
  //! ߥ塼Ⱦ֡
  bool bMute;
  //! ϿݡȾ֡
  bool bRecPort;
  //! LADSPAեȤν硣
  QValueVector<CLadspaEffect> vEffects;
  //! Хѥ֡
  bool bBypass;
};

#endif
